@@ -5,7 +5,7 @@
 %%% Created :  8 Aug 2009 by Evgeniy Khramtsov <ekhramtsov@process-one.net>
 %%%
 %%%
-%%% Copyright (C) 2002-2022 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2023 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -134,9 +134,7 @@ init([Sock, Opts]) ->
 			    {ok, session_established, NewState};
 			{error, Reason} ->
 			    {stop, Reason}
-		    end;
-		{error, Reason} ->
-		    {stop, Reason}
+		    end
 	    end;
 	{error, Reason} ->
 	    {stop, Reason}
@@ -760,9 +758,7 @@ get_sockmod(Opts, Sock) ->
 		true ->
 		    {ok, fast_tls};
 		false ->
-		    {ok, gen_tcp};
-		{error, _Reason} = Err ->
-		    Err
+		    {ok, gen_tcp}
 	    end
     end.
 
@@ -788,9 +784,9 @@ is_tls_handshake({_, _, {_, Socket}}) ->
 	{ok, {_, _}} ->
 	    ?LOG_DEBUG("Determined transport protocol: TCP"),
 	    false;
-	{error, Reason} = Err ->
+	{error, Reason} ->
 	    ?LOG_INFO("Cannot determine transport protocol: ~s", [Reason]),
-	    Err
+	    false
     end.
 -endif.
 
